<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX ネットワーク・アシスタント</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>Status</source>
        <translation>ステータス</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>IP address</source>
        <translation>IP アドレス</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Hardware detected</source>
        <translation>ハードウェアの検出</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Enable</source>
        <translation>有効化</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <location filename="../mainwindow.ui" line="603"/>
        <location filename="../mainwindow.ui" line="712"/>
        <source>Re-scan</source>
        <translation>再スキャン</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Enabled</source>
        <translation>有効</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Interface</source>
        <translation>インターフェース</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>Driver</source>
        <translation>ドライバ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Description</source>
        <translation>説明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Vendor</source>
        <translation>ベンダ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Product</source>
        <translation>製品</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Disable</source>
        <translation>無効化</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Active interface</source>
        <translation>アクティブなインターフェース</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>WiFi status</source>
        <translation>WiFi ステータス</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>全ての無線デバイスのブロックを解除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>Unblock WiFi Devices</source>
        <translation>Wi-Fi デバイスのブロック解除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Linux drivers</source>
        <translation>Linux ドライバ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Associated Linux drivers</source>
        <translation>関連の Linux ドライバ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Load Driver</source>
        <translation>ドライバの読み込み</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>Unload Driver</source>
        <translation>ドライバの読み込み解除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="622"/>
        <location filename="../mainwindow.cpp" line="833"/>
        <source>Block Driver</source>
        <translation>デバイスをブロック</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="640"/>
        <source>Windows drivers</source>
        <translation>Windows ドライバ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Available Windows drivers</source>
        <translation>利用可能な Windowsドライバ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Remove Driver</source>
        <translation>ドライバを削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="690"/>
        <source>Add Driver</source>
        <translation>ドライバを追加</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="729"/>
        <source>About NDISwrapper</source>
        <translation>NDISwrapper について</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="741"/>
        <source>Install NDISwrapper</source>
        <translation>NDISwrapper のインストール</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="751"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Windowsドライバを使用するためには、まず NDISwrapper をインストールする必要があります</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="767"/>
        <source>Uninstall NDISwrapper</source>
        <translation>NDISwrapper を削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>Net diagnostics</source>
        <translation>ネット診断</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="810"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <location filename="../mainwindow.ui" line="933"/>
        <source>Target URL:</source>
        <translation>送出先 URL:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="826"/>
        <source>Packets</source>
        <translation>パケット</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <location filename="../mainwindow.ui" line="991"/>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="1007"/>
        <source>Clear</source>
        <translation>クリア</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <location filename="../mainwindow.ui" line="1020"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="927"/>
        <source>Traceroute</source>
        <translation>トレースルート</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="943"/>
        <source>Hops</source>
        <translation>Hops</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>ルーターの IP アドレス:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>外部 IP アドレス:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>インターフェース: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>ドライバ: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>説明: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>製品: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>ベンダ: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>有効: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>コピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="211"/>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>すべてコピー(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>トレースルートがインストールされていません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>トレースルートがインストールされていません。今すぐインストールを行いますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>トレースルートをインストールできませんでした</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>トレースルートをインストールできません。これは LiveCD を使用しているか、ソフトウェアリポジトリへ接続できないからです。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>トレースルートがインストールされておらず、インターネットに接続されていないためインストールできません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>宛先のホストは存在しません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>宛先ホスト欄を入力して下さい</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>ロードしたドライバー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>ロードしていないドライバー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>ブロックしたデバイス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>ブロックした Broadcom ドライバ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>Ndiswrapper はインストールされていません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>ドライバはインストール済み</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation>で使用中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation> 代替ドライバー:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>ブロックリストから除外されたドライバ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>ブロックリストから除外されたドライバ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>モジュールはブロック中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>インストール完了</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>エラーを検出しました。ndiswrapper ドライバをコンパイルできませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>エラーを検出したので ndiswrapper をインストールできませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>ndiswrapper の削除中にエラーが発生しました</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>ドライバのブロックを解除</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>有効化</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>無効化</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>WiFi のハードウェアスイッチがオフです</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>追加する Windows ドライバを探します</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Windows インストール情報ファイル (*.inf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>*.sys ファイルが見つかりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>*.sys ファイルは *.infファイルと同じ場所にある必要があります。  %1 が見つかりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>参照する sys ファイルが見つかりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>指定 sys ファイルのドライバは、inf ファイルを解析しても決定することができません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Ndiswrapper ドライバを削除しました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>デバイスのロック解除を行えません。
Wi-Fi デバイスはすでにロック解除されたようです。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>Wi-Fi デバイスのロックを解除しました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>バージョン：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>MX Linux のネットワーク設定とトラブル解決を行うプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Copyright (c) MEPIS LLC and MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>ドライバは正常に読み込みまれました</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>ドライバの読み込みを無効にしました</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <location filename="../main.cpp" line="78"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>root としてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation>このプログラムは管理者権限で実行してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>読み込めませんでした</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>アンロードできませんでした</translation>
    </message>
</context>
</TS>